==> payara-embedded-all-5.2020.4-sources.jar: fish/payara/microprofile/metrics/MetricUnitsUtils.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2020 Payara Foundation and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://github.com/payara/Payara/blob/master/LICENSE.txt
 * See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * The Payara Foundation designates this particular file as subject to the "Classpath"
 * exception as provided by the Payara Foundation in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package fish.payara.microprofile.metrics;

import org.eclipse.microprofile.metrics.Metadata;
import org.eclipse.microprofile.metrics.MetricUnits;

/**
 * Utilities around {@link MetricUnits}.
 *
 * @author Jan Bernitt
 */
public final class MetricUnitsUtils {

    private MetricUnitsUtils() {
        throw new UnsupportedOperationException("util");
    }

    public static String baseUnit(String unit) {
        switch (unit) {
        case MetricUnits.BITS:
        case MetricUnits.KILOBITS:
        case MetricUnits.MEGABITS:
        case MetricUnits.GIGABITS:
        case MetricUnits.KIBIBITS:
        case MetricUnits.MEBIBITS:
        case MetricUnits.GIBIBITS:
        case MetricUnits.BYTES:
        case MetricUnits.KILOBYTES:
        case MetricUnits.MEGABYTES:
        case MetricUnits.GIGABYTES:
            return MetricUnits.BYTES;
        case MetricUnits.NANOSECONDS:
        case MetricUnits.MICROSECONDS:
        case MetricUnits.MILLISECONDS:
        case MetricUnits.SECONDS:
        case MetricUnits.MINUTES:
        case MetricUnits.HOURS:
        case MetricUnits.DAYS:
            return MetricUnits.SECONDS;
        default:
            return unit;
        }
    }

    public static Number scaleToBaseUnit(Number value, Metadata metadata) {
        if (!metadata.getUnit().isPresent()) {
            return value;
        }
        String unit = metadata.getUnit().get();
        return scaleToBaseUnit(value, unit);
    }

    public static Number scaleToBaseUnit(Number value, String unit) {
        if (unit == null || unit.isEmpty() || unit.equals(MetricUnits.NONE)) {
            return value;
        }
        switch (unit) {
        // bytes from bits
        case MetricUnits.BITS: return value.longValue() / 8d;
        case MetricUnits.KILOBITS: return value.doubleValue() * 1000d / 8d;
        case MetricUnits.MEGABITS: return value.doubleValue() * 1000d * 1000d / 8d;
        case MetricUnits.GIGABITS: return value.doubleValue() * 1000d * 1000d * 1000d / 8d;
        case MetricUnits.KIBIBITS: return value.doubleValue() * 1024d / 8d;
        case MetricUnits.MEBIBITS: return value.doubleValue() * 1024d * 1024d / 8d;
        case MetricUnits.GIBIBITS: return value.doubleValue() * 1024d * 1024d * 1024d / 8d;

        // bytes from bytes
        case MetricUnits.BYTES: return value;
        case MetricUnits.KILOBYTES: return value.doubleValue() * 1000d;
        case MetricUnits.MEGABYTES: return value.doubleValue() * 1000d * 1000d;
        case MetricUnits.GIGABYTES: return value.doubleValue() * 1000d * 1000d * 1000d;

        // seconds from time unit
        case MetricUnits.NANOSECONDS: return value.longValue()  / 1000d / 1000d / 1000d;
        case MetricUnits.MICROSECONDS: return value.longValue() / 1000d / 1000d;
        case MetricUnits.MILLISECONDS: return value.longValue() / 1000d;
        case MetricUnits.SECONDS: return value;
        case MetricUnits.MINUTES: return value.doubleValue() * 60d;
        case MetricUnits.HOURS: return value.doubleValue() * 60d * 60d;
        case MetricUnits.DAYS: return value.doubleValue() * 60d * 60d * 24d;

        // others
        case MetricUnits.PERCENT:
        case MetricUnits.PER_SECOND:
        default:
            return value;
        }
    }

}

==> payara-embedded-all-6.2023.2-sources.jar: fish/payara/microprofile/metrics/MetricUnitsUtils.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2020 Payara Foundation and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://github.com/payara/Payara/blob/master/LICENSE.txt
 * See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * The Payara Foundation designates this particular file as subject to the "Classpath"
 * exception as provided by the Payara Foundation in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package fish.payara.microprofile.metrics;

import org.eclipse.microprofile.metrics.Metadata;
import org.eclipse.microprofile.metrics.MetricUnits;

/**
 * Utilities around {@link MetricUnits}.
 *
 * @author Jan Bernitt
 */
public final class MetricUnitsUtils {

    private MetricUnitsUtils() {
        throw new UnsupportedOperationException("util");
    }

    public static String baseUnit(String unit) {
        switch (unit) {
        case MetricUnits.BITS:
        case MetricUnits.KILOBITS:
        case MetricUnits.MEGABITS:
        case MetricUnits.GIGABITS:
        case MetricUnits.KIBIBITS:
        case MetricUnits.MEBIBITS:
        case MetricUnits.GIBIBITS:
        case MetricUnits.BYTES:
        case MetricUnits.KILOBYTES:
        case MetricUnits.MEGABYTES:
        case MetricUnits.GIGABYTES:
            return MetricUnits.BYTES;
        case MetricUnits.NANOSECONDS:
        case MetricUnits.MICROSECONDS:
        case MetricUnits.MILLISECONDS:
        case MetricUnits.SECONDS:
        case MetricUnits.MINUTES:
        case MetricUnits.HOURS:
        case MetricUnits.DAYS:
            return MetricUnits.SECONDS;
        default:
            return unit;
        }
    }

    public static Number scaleToBaseUnit(Number value, Metadata metadata) {
        if (!metadata.unit().isPresent()) {
            return value;
        }
        String unit = metadata.getUnit();
        return scaleToBaseUnit(value, unit);
    }

    public static Number scaleToBaseUnit(Number value, String unit) {
        if (unit == null || unit.isEmpty() || unit.equals(MetricUnits.NONE)) {
            return value;
        }
        switch (unit) {
        // bytes from bits
        case MetricUnits.BITS: return value.longValue() / 8d;
        case MetricUnits.KILOBITS: return value.doubleValue() * 1000d / 8d;
        case MetricUnits.MEGABITS: return value.doubleValue() * 1000d * 1000d / 8d;
        case MetricUnits.GIGABITS: return value.doubleValue() * 1000d * 1000d * 1000d / 8d;
        case MetricUnits.KIBIBITS: return value.doubleValue() * 1024d / 8d;
        case MetricUnits.MEBIBITS: return value.doubleValue() * 1024d * 1024d / 8d;
        case MetricUnits.GIBIBITS: return value.doubleValue() * 1024d * 1024d * 1024d / 8d;

        // bytes from bytes
        case MetricUnits.BYTES: return value;
        case MetricUnits.KILOBYTES: return value.doubleValue() * 1000d;
        case MetricUnits.MEGABYTES: return value.doubleValue() * 1000d * 1000d;
        case MetricUnits.GIGABYTES: return value.doubleValue() * 1000d * 1000d * 1000d;

        // seconds from time unit
        case MetricUnits.NANOSECONDS: return value.longValue()  / 1000d / 1000d / 1000d;
        case MetricUnits.MICROSECONDS: return value.longValue() / 1000d / 1000d;
        case MetricUnits.MILLISECONDS: return value.longValue() / 1000d;
        case MetricUnits.SECONDS: return value;
        case MetricUnits.MINUTES: return value.doubleValue() * 60d;
        case MetricUnits.HOURS: return value.doubleValue() * 60d * 60d;
        case MetricUnits.DAYS: return value.doubleValue() * 60d * 60d * 24d;

        // others
        case MetricUnits.PERCENT:
        case MetricUnits.PER_SECOND:
        default:
            return value;
        }
    }

}
